@@ -1,5 +1,5 @@
 ;; maximize.jl -- window maximization
-;; $Id: maximize.jl,v 1.56 2001/03/06 19:55:19 jsh Exp $
+;; $Id: maximize.jl,v 1.58 2001/03/26 19:35:19 jsh Exp $
 
 ;; Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -147,13 +147,15 @@
 		 (not (window-maximized-horizontally-p w)))
 	(window-put w 'unmaximized-geometry nil))))
 
-  (define (maximize-discard-move w directions)
-    (maximize-discard w (memq 'horizontal directions)
-		      (memq 'vertical directions)))
+  (define (maximize-discard-move w directions #!key successful)
+    (when successful
+      (maximize-discard w (memq 'horizontal directions)
+			(memq 'vertical directions))))
 
-  (define (maximize-discard-resize w edges)
-    (maximize-discard w (or (memq 'left edges) (memq 'right edges))
-		      (or (memq 'top edges) (memq 'bottom edges))))
+  (define (maximize-discard-resize w edges #!key successful)
+    (when successful
+      (maximize-discard w (or (memq 'left edges) (memq 'right edges))
+			(or (memq 'top edges) (memq 'bottom edges)))))
 
 
 ;;; 1D packing
@@ -326,12 +328,14 @@
   (define (maximize-find-workarea #!optional w #!key head)
     "Return the rectangle representing the largest rectangle on the screen that
 doesn't overlap any avoided windows, or nil."
+    (unless head
+      (setq head (current-head w)))
     (let* ((avoided (avoided-windows w))
 	   (edges (get-visible-window-edges
 		   #:with-ignored-windows t
 		   #:windows avoided
-		   #:include-heads (list (or head (current-head))))))
-      (find-max-rectangle avoided edges (current-head w))))
+		   #:include-heads (list head))))
+      (find-max-rectangle avoided edges head)))
 
   (define (frame-part-movable-p w part)
     (if (not move-lock-when-maximized)
@@ -360,7 +364,7 @@ doesn't overlap any avoided windows, or nil."
 	   (edges (get-visible-window-edges
 		   #:with-ignored-windows t
 		   #:windows avoided
-		   #:include-heads (list (current-head)))))
+		   #:include-heads (list (current-head w)))))
       (when (window-maximizable-p w direction hints)
 	(unless (window-get w 'unmaximized-geometry)
 	  (window-put w 'unmaximized-geometry (list (car coords) (cdr coords)
