@@ -1,5 +1,5 @@
 ;; workspace.jl -- similar to virtual desktops
-;; $Id: workspace.jl,v 1.145 2001/03/01 04:35:44 jsh Exp $
+;; $Id: workspace.jl,v 1.146 2001/04/11 21:02:09 jsh Exp $
 
 ;; Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -935,6 +935,11 @@ last instance remaining, then delete the actual window."
   (add-hook 'workspace-geometry-changed
 	    (lambda ()
 	      (setq preallocated-workspaces (car workspace-geometry))
+	      ;; XXX this isn't ideal, but it's better than getting
+	      ;; XXX workspaces that aren't deleted as the total
+	      ;; XXX number of workspaces is decreased...
+	      (setq first-interesting-workspace nil)
+	      (setq last-interesting-workspace nil)
 	      (call-hook 'workspace-state-change-hook)))
 
 
