@@ -1,5 +1,5 @@
 /* events.c -- Event handling
-   $Id: events.c,v 1.137 2001/02/20 00:04:57 jsh Exp $
+   $Id: events.c,v 1.139 2001/06/05 03:54:12 jsh Exp $
 
    Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -771,9 +771,7 @@ unmap_notify (XEvent *ev)
 	}
 	Fcall_window_hook (Qunmap_notify_hook, rep_VAL(w), Qnil, Qnil);
 
-	if (focus_window == w)
-	    focus_on_window (0);
-
+	focus_off_window (w);
 	XDeleteProperty (dpy, w->id, xa_wm_state);
     }
 }
@@ -887,6 +885,9 @@ focus_in (XEvent *ev)
     if (w != 0 && w->visible)
     {
 	focus_window = w;
+	if (pending_focus_window == w)
+	    pending_focus_window = 0;
+
 	if (last_focused != w)
 	{
 	    last_focused = w;
@@ -1042,7 +1043,8 @@ configure_request (XEvent *ev)
 	{
 	    /* Be sure to send one (and only one) synthetic ConfigureNotify
 	       to the window. The ICCCM states that we should send the event
-	       even if the state of the window doesn't change */
+	       even if the state of the window doesn't change. But not
+	       if the window has been resized */
 
 	    Fsynthetic_configure_mutex (Qt);
 	    send_synthetic_configure (w);
