@@ -1,5 +1,5 @@
 /* windows.c -- window manipulation
-   $Id: windows.c,v 1.113 2001/02/20 01:32:13 jsh Exp $
+   $Id: windows.c,v 1.115 2001/06/05 03:54:12 jsh Exp $
 
    Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -23,15 +23,10 @@
 #include <assert.h>
 #include <X11/extensions/shape.h>
 
-/* Work around for X11R5 and earlier */
-#ifndef XUrgencyHint
-#define XUrgencyHint (1 << 8)
-#endif
-
 Lisp_Window *window_list;
 int window_type;
 
-Lisp_Window *focus_window;
+Lisp_Window *focus_window, *pending_focus_window;
 
 int pending_destroys;
 
@@ -143,17 +138,31 @@ focus_on_window (Lisp_Window *w)
 	if (focus != 0)
 	{
 	    XSetInputFocus (dpy, focus, RevertToParent, last_event_time);
-	    focus_window = w;
+	    pending_focus_window = w;
 	}
     }
     else
     {
 	DB(("focus_on_window (nil)\n"));
 	XSetInputFocus (dpy, no_focus_window, RevertToNone, last_event_time);
-	focus_window = 0;
+	pending_focus_window = 0;
     }
 }
 
+/* Should be called when W is no longer focusable. */
+void
+focus_off_window (Lisp_Window *w)
+{
+    if (focus_window == w)
+    {
+	focus_window = 0;
+	if (pending_focus_window == 0 || pending_focus_window == w)
+	    focus_on_window (0);
+    }
+    if (pending_focus_window == w)
+	pending_focus_window = 0;
+}
+
 /* Set flags in W relating to which window manager protocols are recognised
    by window W. */
 void
@@ -485,7 +494,11 @@ remove_window (Lisp_Window *w, repv destroyed, repv from_error)
 	int revert_to;
 	XGetInputFocus (dpy, &focus, &revert_to);
 	if (focus == None || focus == PointerRoot)
-	    focus_on_window (focus_window);
+	{
+	    DB (("lost focus (%ld)\n", focus));
+	    focus_on_window (pending_focus_window
+			     ? pending_focus_window : focus_window);
+	}
     }
 }
 
@@ -516,8 +529,7 @@ emit_pending_destroys (void)
 		Fcall_window_hook (Qdestroy_notify_hook,
 				   rep_VAL(w), Qnil, Qnil);
 
-		if (focus_window == w)
-		    focus_on_window (0);
+		focus_off_window (w);
 
 		/* gc may have reordered the list, so we have to start
 		   at the beginning again.. */
